import pytest

import pystv
from pystv import RaceInfo
from pystv import RaceMetadata as RM

PARSE_HEADER_DATA = [
    (["Q0 [A00]"], [(RM("Q0", 1, ["A00"]), slice(0, 1))]),
    (["T", "Q0 [A00]", "Q0 [A01]"], [(RM("Q0", 1, ["A00", "A01"]), slice(1, 3))]),
    (["Q0 [A00]", "Q0 [A01]"], [(RM("Q0", 1, ["A00", "A01"]), slice(0, 2))]),
    (
        ["Q0 [A00]", "Q0 [A01]", "Q1 [A10]", "Q1 [A11]"],
        [
            (RM("Q0", 1, ["A00", "A01"]), slice(0, 2)),
            (RM("Q1", 1, ["A10", "A11"]), slice(2, 4)),
        ],
    ),
    (
        ["T", "Q0 [A00]", "Q0 [A01]", "T", "Q1 [A10]", "Q1 [A11]", "T"],
        [
            (RM("Q0", 1, ["A00", "A01"]), slice(1, 3)),
            (RM("Q1", 1, ["A10", "A11"]), slice(4, 6)),
        ],
    ),
]


@pytest.mark.parametrize("header,expected", PARSE_HEADER_DATA)
def test_parse_header(header, expected):
    assert pystv.parse_header(header) == expected


def test_parse_rows():
    rows = [
        ["Q0 [A00]", "Q0 [A01]", "Q0 [A02]"],
        [1, 2, 3],
        [3, 1, 2],
        [2, 1, 3],
        [2, 1, 3],
        [1, 2, 3],
    ]
    actual = pystv.parse_rows(rows)

    metadata = RM("Q0", 1, ["A00", "A01", "A02"])
    expected = [RaceInfo(metadata, [[1, 2, 3], [2, 1, 3], [3, 1, 2]], [2, 2, 1])]

    assert actual == expected
